@@ -166,15 +166,15 @@ void writeMscGraphFromFile(const QCString &inFile,const QCString &outDir,
   QCString imgName = absOutFile;
   switch (format)
   {
-    case MSC_BITMAP:
+    case MscOutputFormat::BITMAP:
       msc_format = mscgen_format_png;
       imgName+=".png";
       break;
-    case MSC_EPS:
+    case MscOutputFormat::EPS:
       msc_format = mscgen_format_eps;
       imgName+=".eps";
       break;
-    case MSC_SVG:
+    case MscOutputFormat::SVG:
       msc_format = mscgen_format_svg;
       imgName+=".svg";
       break;
@@ -186,7 +186,7 @@ void writeMscGraphFromFile(const QCString &inFile,const QCString &outDir,
     return;
   }
 
-  if ( (format==MSC_EPS) && (Config_getBool(USE_PDFLATEX)) )
+  if ( (format==MscOutputFormat::EPS) && (Config_getBool(USE_PDFLATEX)) )
   {
     QCString epstopdfArgs(maxCmdLine, QCString::ExplicitSize);
     epstopdfArgs.sprintf("\"%s.eps\" --outfile=\"%s.pdf\"",
@@ -196,6 +196,10 @@ void writeMscGraphFromFile(const QCString &inFile,const QCString &outDir,
       err_full(srcFile,srcLine,"Problems running epstopdf when processing '%s.eps'. Check your TeX installation!",
           qPrint(absOutFile));
     }
+    else
+    {
+      Dir().remove((absOutFile + ".eps").data());
+    }
   }
 
   int i=std::max(imgName.findRev('/'),imgName.findRev('\\'));
@@ -240,19 +244,19 @@ void writeMscImageMapFromFile(TextStream &t,const QCString &inFile,
   t << "<img src=\"" << relPath << baseName << ".";
   switch (format)
   {
-    case MSC_BITMAP:
+    case MscOutputFormat::BITMAP:
       t << "png";
       break;
-    case MSC_EPS:
+    case MscOutputFormat::EPS:
       t << "eps";
       break;
-    case MSC_SVG:
+    case MscOutputFormat::SVG:
       t << "svg";
       break;
     default:
       t << "unknown";
   }
-  QCString imap = getMscImageMapFromFile(inFile,outDir,relPath,context,format==MSC_SVG,srcFile,srcLine);
+  QCString imap = getMscImageMapFromFile(inFile,outDir,relPath,context,format==MscOutputFormat::SVG,srcFile,srcLine);
   if (!imap.isEmpty())
   {
     t << "\" alt=\""
